@@ -6,7 +6,7 @@ package Mail::DomainKeys::Key;
 
 use strict;
 
-our $VERSION = "0.14";
+our $VERSION = "0.21";
 
 sub cork {
 	my $self = shift;
@@ -29,6 +29,15 @@ sub data {
 	$self->{'DATA'};
 }
 
+sub errorstr {
+	my $self = shift;
+
+	(@_) and 
+		$self->{'ESTR'} = shift;
+
+	$self->{'ESTR'};
+}
+
 sub size {
 	my $self = shift;
 
